%
% function Pendel_3( w0, v0, tm, d )
%    Pendel-Schwingung, vollständig, mit Reibung
%       w0 : Anfangswinkel in Radiant
%       v0 : Anfangswinkelgeschwindigkeit
%       tm : Länge des Zeitintervalls in Sekunden
%       d  : Reibungskoeffizient
%
%       Beispiel-Aufrufe: 
%          Pendel_3( 0.1, 0, 10, 0.1 ) - schwache Dämpfung
%          Pendel_3( 0.1, 0, 10,  1 )  - starke Dämpfung
%          Pendel_3( 2.8, -2, 5,  0  ) - durchschlagend
%          Pendel_3( 2.8, -2, 5, 0.1 ) - periodisch mit Dämpfung
%          Pendel_3( 2.8, -5, 5, 0.1 ) - ein Durchschlag
%
%    zugehörige DGL-Funktion: Pendel_3_Fun.m
%
function  Pendel_3( w0, v0, tm, d )

   % Pendel-Konstanten
   L = 0.5;   % Fadenlänge, 0.5 m, 
   g = 9.81;  % 9.81 m/s2: Erdbeschleunigung
   
   % Variable für die DGL-Funktion
   gVar = g / L;
   delta = 2 * d;
   
   % Anfangswerte
   y0 = [ w0, v0 ];
   % Zeit-Intervall
   tspan = [0,tm];
   
   % Lösung des Anfangswert-Problems
   [t,y] = ode45( @Pendel_3_Fun, tspan, y0, [], gVar, delta  );
   % daraus den Funktionswert - 1. Komponente
   z = y( :, 1 );
    
   % alles plotten
   plot( t, z );
   grid on; 
end  